from pathlib import Path
import requests


class Downloader:
    url: str
    output_path: Path

    def configure(self, url: str, output_path: Path):
        self.url = url
        self.output_path = Path(output_path)

    def download(self):
        response = requests.get(self.url)

        if response.status_code == 200:
            self.output_path.write_bytes(response.content)
            # with open(output_path, 'wb') as f:
            #     f.write(response.content)



from orpytlex.classes.downloader import Downloader


def main():
    downloader = Downloader()
    url = 'http://mirror-osd.de.bosch.com/ms-teams/dists/stable/main/binary-amd64/Packages.gz'
    downloader.configure(
        url=url,
        output_path='/tmp/Packages.gz',
    )
    print('Downloading file...')
    downloader.download()
    print('Done!')


if __name__ == '__main__':
    main()
